@@ -17,6 +17,7 @@ struct ly_ctx;
 #define LY_CTX_LEAFREF_EXTENDED ...
 #define LY_CTX_LEAFREF_LINKING ...
 #define LY_CTX_BUILTIN_PLUGINS_ONLY ...
+#define LY_CTX_COMPILE_OBSOLETE ...
 
 
 typedef enum {
@@ -304,20 +305,19 @@ enum lyd_type {
     LYD_TYPE_REPLY_RESTCONF
 };
 
-#define LYD_PRINT_KEEPEMPTYCONT ...
 #define LYD_PRINT_SHRINK   ...
+#define LYD_PRINT_EMPTY_CONT ...
 #define LYD_PRINT_WD_ALL ...
 #define LYD_PRINT_WD_ALL_TAG ...
 #define LYD_PRINT_WD_EXPLICIT ...
 #define LYD_PRINT_WD_IMPL_TAG ...
 #define LYD_PRINT_WD_MASK ...
-#define LYD_PRINT_WITHSIBLINGS ...
+#define LYD_PRINT_SIBLINGS ...
 #define LYD_PRINT_WD_TRIM ...
 LY_ERR lyd_print_mem(char **, const struct lyd_node *, LYD_FORMAT, uint32_t);
 LY_ERR lyd_print_tree(struct ly_out *, const struct lyd_node *, LYD_FORMAT, uint32_t);
 LY_ERR lyd_print_all(struct ly_out *, const struct lyd_node *, LYD_FORMAT, uint32_t);
 
-#define LYD_PARSE_LYB_MOD_UPDATE ...
 #define LYD_PARSE_NO_STATE ...
 #define LYD_PARSE_STORE_ONLY ...
 #define LYD_PARSE_JSON_NULL ...
@@ -351,7 +351,7 @@ LY_ERR ly_out_new_file(FILE *, struct ly_out **);
 LY_ERR ly_out_new_fd(int, struct ly_out **);
 
 LY_ERR lyd_parse_data(const struct ly_ctx *, struct lyd_node *, struct ly_in *, LYD_FORMAT, uint32_t, uint32_t, struct lyd_node **);
-LY_ERR lyd_parse_op(const struct ly_ctx *, struct lyd_node *, struct ly_in *, LYD_FORMAT, enum lyd_type, struct lyd_node **, struct lyd_node **);
+LY_ERR lyd_parse_op(const struct ly_ctx *, struct lyd_node *, struct ly_in *, LYD_FORMAT, enum lyd_type, uint32_t, struct lyd_node **, struct lyd_node **);
 
 typedef enum {
    LYS_OUT_UNKNOWN,
@@ -369,6 +369,7 @@ LY_ERR lys_print_module(struct ly_out *, const struct lys_module *, LYS_OUTFORMA
 
 struct lysc_module {
 	struct lys_module *mod;
+	const char **features;
 	struct lysc_node *data;
 	struct lysc_node_action *rpcs;
 	struct lysc_node_notif *notifs;
@@ -388,13 +389,15 @@ struct lys_module {
     const char *ref;
     struct lysp_module *parsed;
     struct lysc_module *compiled;
+    struct lysc_ext *extensions;
     struct lysc_ident *identities;
+    struct lysc_submodule *submodules;
     struct lys_module **augmented_by;
     struct lys_module **deviated_by;
     ly_bool implemented;
     ly_bool to_compile;
-    uint8_t latest_revision;
-    ...;
+    uint8_t version : 2;
+    uint8_t latest_revision : 4;
 };
 
 struct lysp_module {
@@ -467,12 +470,11 @@ struct lysp_ext_instance {
     const char *argument;
     LY_VALUE_FORMAT format;
     void *prefix_data;
-    struct lysp_ext *def;
+    uintptr_t plugin_ref;
     void *parent;
     enum ly_stmt parent_stmt;
     uint64_t parent_stmt_index;
     uint16_t flags;
-    const struct lyplg_ext_record *record;
     struct lysp_ext_substmt *substmts;
     void *parsed;
     struct lysp_stmt *child;
@@ -610,6 +612,11 @@ struct lysp_node_container {
     ...;
 };
 
+struct lysc_value {
+    const char *str;
+    struct lysc_prefix *prefixes;
+};
+
 struct lysc_node_leaf {
     union {
         struct lysc_node node;
@@ -623,7 +630,7 @@ struct lysc_node_leaf {
     struct lysc_when **when;
     struct lysc_type *type;
     const char *units;
-    struct lyd_value *dflt;
+    struct lysc_value dflt;
     ...;
 };
 
@@ -653,7 +660,7 @@ struct lysc_node_leaflist {
     struct lysc_when **when;
     struct lysc_type *type;
     const char *units;
-    struct lyd_value **dflts;
+    struct lysc_value *dflts;
     uint32_t min;
     uint32_t max;
     ...;
@@ -783,7 +790,7 @@ struct lysp_node_augment {
 struct lysc_type {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
 };
@@ -859,7 +866,7 @@ struct lysc_ext {
     const char *name;
     const char *argname;
     struct lysc_ext_instance *exts;
-    struct lyplg_ext *plugin;
+    uintptr_t plugin_ref;
     struct lys_module *module;
     uint16_t flags;
 };
@@ -982,7 +989,6 @@ typedef struct pcre2_real_code pcre2_code;
 
 struct lysc_pattern {
     const char *expr;
-    pcre2_code *code;
     const char *dsc;
     const char *ref;
     const char *emsg;
@@ -1017,7 +1023,7 @@ struct lysc_ident {
 struct lysc_type_num {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_range *range;
@@ -1026,7 +1032,7 @@ struct lysc_type_num {
 struct lysc_type_dec {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     uint8_t fraction_digits;
@@ -1036,7 +1042,7 @@ struct lysc_type_dec {
 struct lysc_type_str {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_range *length;
@@ -1058,7 +1064,7 @@ struct lysc_type_bitenum_item {
 struct lysc_type_enum {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_type_bitenum_item *enums;
@@ -1067,7 +1073,7 @@ struct lysc_type_enum {
 struct lysc_type_bits {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_type_bitenum_item *bits;
@@ -1076,7 +1082,7 @@ struct lysc_type_bits {
 struct lysc_type_leafref {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lyxp_expr *path;
@@ -1088,7 +1094,7 @@ struct lysc_type_leafref {
 struct lysc_type_identityref {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_ident **bases;
@@ -1097,7 +1103,7 @@ struct lysc_type_identityref {
 struct lysc_type_instanceid {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     uint8_t require_instance;
@@ -1106,7 +1112,7 @@ struct lysc_type_instanceid {
 struct lysc_type_union {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_type **types;
@@ -1115,7 +1121,7 @@ struct lysc_type_union {
 struct lysc_type_bin {
     const char *name;
     struct lysc_ext_instance *exts;
-    struct lyplg_type *plugin;
+    uintptr_t plugin_ref;
     LY_DATA_TYPE basetype;
     uint32_t refcount;
     struct lysc_range *length;
@@ -1159,8 +1165,7 @@ typedef enum {
    LYD_ANYDATA_DATATREE,
    LYD_ANYDATA_STRING,
    LYD_ANYDATA_XML,
-   LYD_ANYDATA_JSON,
-   LYD_ANYDATA_LYB
+   LYD_ANYDATA_JSON
 } LYD_ANYDATA_VALUETYPE;
 
 union lyd_any_value {
@@ -1168,7 +1173,6 @@ union lyd_any_value {
     const char *str;
     const char *xml;
     const char *json;
-    char *mem;
 };
 
 struct lyd_node_any {
@@ -1320,6 +1324,8 @@ struct lyd_attr {
 LY_ERR lyd_new_attr(struct lyd_node *, const char *, const char *, const char *, struct lyd_attr **);
 void lyd_free_attr_single(const struct ly_ctx *ctx, struct lyd_attr *attr);
 
+LY_ERR lyd_value_validate_dflt(const struct lysc_node *, const char *, struct lysc_prefix *, const struct lyd_node *, const struct lysc_type **, const char **);
+
 struct lyd_leafref_links_rec {
     const struct lyd_node_term *node;
     const struct lyd_node_term **leafref_nodes;
@@ -1328,13 +1334,14 @@ struct lyd_leafref_links_rec {
 
 LY_ERR lyd_leafref_get_links(const struct lyd_node_term *, const struct lyd_leafref_links_rec **);
 LY_ERR lyd_leafref_link_node_tree(struct lyd_node *);
+struct lyplg_ext *lysc_get_ext_plugin(uintptr_t);
 const char *lyplg_ext_stmt2str(enum ly_stmt stmt);
 const struct lysp_module *lyplg_ext_parse_get_cur_pmod(const struct lysp_ctx *);
 struct ly_ctx *lyplg_ext_compile_get_ctx(const struct lysc_ctx *);
 void lyplg_ext_parse_log(const struct lysp_ctx *, const struct lysp_ext_instance *, LY_LOG_LEVEL, LY_ERR, const char *, ...);
 void lyplg_ext_compile_log(const struct lysc_ctx *, const struct lysc_ext_instance *, LY_LOG_LEVEL, LY_ERR, const char *, ...);
 LY_ERR lyplg_ext_parse_extension_instance(struct lysp_ctx *, struct lysp_ext_instance *);
-LY_ERR lyplg_ext_compile_extension_instance(struct lysc_ctx *, const struct lysp_ext_instance *, struct lysc_ext_instance *);
+LY_ERR lyplg_ext_compile_extension_instance(struct lysc_ctx *, const struct lysp_ext_instance *, struct lysc_ext_instance *, struct lysc_node *);
 void lyplg_ext_pfree_instance_substatements(const struct ly_ctx *ctx, struct lysp_ext_substmt *substmts);
 void lyplg_ext_cfree_instance_substatements(const struct ly_ctx *ctx, struct lysc_ext_substmt *substmts);
 typedef LY_ERR (*lyplg_ext_parse_clb)(struct lysp_ctx *, struct lysp_ext_instance *);
