@@ -205,6 +205,7 @@ class Context:
         builtin_plugins_only: bool = False,
         all_implemented: bool = False,
         enable_imp_features: bool = False,
+        compile_obsolete: bool = False,
         yanglib_path: Optional[str] = None,
         yanglib_fmt: str = "json",
         cdata=None,  # C type: "struct ly_ctx *"
@@ -231,6 +232,8 @@ class Context:
             options |= lib.LY_CTX_ALL_IMPLEMENTED
         if enable_imp_features:
             options |= lib.LY_CTX_ENABLE_IMP_FEATURES
+        if compile_obsolete:
+            options |= lib.LY_CTX_COMPILE_OBSOLETE
         # force priv parsed
         options |= lib.LY_CTX_SET_PRIV_PARSED
 
@@ -259,6 +262,7 @@ class Context:
                 fmt = lib.LYD_JSON
             else:
                 fmt = lib.LYD_XML
+            print("steweg", search_path, yanglib_path, yanglib_fmt, options)
             ret = lib.ly_ctx_new_ylpath(
                 str2c(search_path), str2c(yanglib_path), fmt, options, ctx
             )
@@ -542,6 +546,8 @@ class Context:
         in_data: Union[IO, str],
         dtype: DataType,
         parent: DNode = None,
+        opaq: bool = False,
+        strict: bool = False,
     ) -> DNode:
         fmt = data_format(fmt)
         data = ffi.new("struct ly_in **")
@@ -551,13 +557,14 @@ class Context:
         if ret != lib.LY_SUCCESS:
             raise self.error("failed to read input data")
 
+        flags = parser_flags(opaq=opaq, strict=strict)
         tree = ffi.new("struct lyd_node **", ffi.NULL)
         op = ffi.new("struct lyd_node **", ffi.NULL)
         par = ffi.new("struct lyd_node **", ffi.NULL)
         if parent is not None:
             par[0] = parent.cdata
 
-        ret = lib.lyd_parse_op(self.cdata, par[0], data[0], fmt, dtype, tree, op)
+        ret = lib.lyd_parse_op(self.cdata, par[0], data[0], fmt, dtype, flags, tree, op)
         lib.ly_in_free(data[0], 0)
         if ret != lib.LY_SUCCESS:
             raise self.error("failed to parse input data")
@@ -570,9 +577,17 @@ class Context:
         data: str,
         dtype: DataType = DataType.DATA_YANG,
         parent: DNode = None,
+        opaq: bool = False,
+        strict: bool = False,
     ):
         return self.parse_op(
-            fmt, in_type=IOType.MEMORY, in_data=data, dtype=dtype, parent=parent
+            fmt,
+            in_type=IOType.MEMORY,
+            in_data=data,
+            dtype=dtype,
+            parent=parent,
+            opaq=opaq,
+            strict=strict,
         )
 
     def parse_data(
@@ -581,7 +596,6 @@ class Context:
         in_type: IOType,
         in_data: Union[str, bytes, IO],
         parent: DNode = None,
-        lyb_mod_update: bool = False,
         no_state: bool = False,
         parse_only: bool = False,
         opaq: bool = False,
@@ -596,7 +610,6 @@ class Context:
         if self.cdata is None:
             raise RuntimeError("context already destroyed")
         parser_flgs = parser_flags(
-            lyb_mod_update=lyb_mod_update,
             no_state=no_state,
             parse_only=parse_only,
             opaq=opaq,
@@ -640,7 +653,6 @@ class Context:
         data: Union[str, bytes],
         fmt: str,
         parent: DNode = None,
-        lyb_mod_update: bool = False,
         no_state: bool = False,
         parse_only: bool = False,
         opaq: bool = False,
@@ -657,7 +669,6 @@ class Context:
             in_type=IOType.MEMORY,
             in_data=data,
             parent=parent,
-            lyb_mod_update=lyb_mod_update,
             no_state=no_state,
             parse_only=parse_only,
             opaq=opaq,
@@ -675,7 +686,6 @@ class Context:
         fileobj: IO,
         fmt: str,
         parent: DNode = None,
-        lyb_mod_update: bool = False,
         no_state: bool = False,
         parse_only: bool = False,
         opaq: bool = False,
@@ -692,7 +702,6 @@ class Context:
             in_type=IOType.FD,
             in_data=fileobj,
             parent=parent,
-            lyb_mod_update=lyb_mod_update,
             no_state=no_state,
             parse_only=parse_only,
             opaq=opaq,
